@@ -35,9 +35,28 @@ class Common(execute.Execute, prepare.Prepare):
     def include(self):
         for i in self.require:
             try:
-                self.modules[i] = importlib.import_module(f"util.{i}")
+                if type(i) == tuple:
+                    try:
+                        m = importlib.import_module(f"{i[0]}.{i[1]}")
+                        name = i[2] if len(i) == 3 else i[1]
+                        self.modules[name] = m
+                    except:
+                        m = importlib.import_module(i[0])
+
+                        if type(i[1]) in [tuple, list]:
+                            for j in i[1]:
+                                self.modules[j] = getattr(m, j)
+                        else:
+                            name = i[2] if len(i) == 3 else i[1]
+                            self.modules[name] = getattr(m, i[1])
+
+                else:
+                    self.modules[i] = importlib.import_module(f"util.{i}")
             except:
-                self.modules[i] = importlib.import_module(i)
+                try:
+                    self.modules[i] = importlib.import_module(i)
+                except:
+                    pass
 
     def haskey(self, data, key, value="", message=""):
         """
@@ -148,6 +167,12 @@ class Common(execute.Execute, prepare.Prepare):
             timeout=params.get("timeout", 3000),
             params=params.get("params"),
         )
+        if self.get("debug"):
+            self.logging.debug(f"getUrl: {params['url']}")
+            if data:
+                self.logging.debug(f"reqData: ${self.dumps(data)}")
+            if json:
+                self.logging.debug(f"reqJson: ${self.dumps(json)}")
         if data:
             args["data"] = data
         elif json:
@@ -171,6 +196,10 @@ class Common(execute.Execute, prepare.Prepare):
         elif response == "response":
             html = {}
             c = module(params["url"], **args)
+            if params.get("decoding"):
+                c.decoding = params["decoding"]
+            elif params.get("encoding"):
+                c.encoding = params["encoding"]
             if params.get("nobody"):
                 html["content"] = ""
             else:
@@ -197,7 +226,10 @@ class Common(execute.Execute, prepare.Prepare):
             return html
         else:
             c = module(params["url"], **args)
-
+            if params.get("decoding"):
+                c.decoding = params["decoding"]
+            elif params.get("encoding"):
+                c.encoding = params["encoding"]
             if response == "json":
                 return c.json()
             else:
@@ -407,7 +439,11 @@ class Common(execute.Execute, prepare.Prepare):
                 else:
                     dict["cookies"] = [dict["cookie"]]
             for k, v in dict.items():
-                self.set(k, v)
+                if k == "ENV":
+                    for kk, vv in v.items():
+                        self.set(kk, vv)
+                else:
+                    self.set(k, v)
             return dict
         except:
             return {}
@@ -484,15 +520,18 @@ class Common(execute.Execute, prepare.Prepare):
                 ["^try\s*\{\s*\n*\s*(\w+)", "^(\w+)\s*\n*\s*\(", "^(\w+\s*=)\s*\{"], s
             )
             if getTry:
-                c = execjs.compile(
-                    """
+                try:
+                    s = json.loads(re.match(".*?({.*}).*", s, re.S).group(1))
+                except:
+                    c = execjs.compile(
+                        """
                     function kk() {
                             return %s;
                         }
                         """
-                    % s.replace(getTry, "cbData=")
-                )
-                s = c.call("kk")
+                        % s.replace(getTry, "cbData=")
+                    )
+                    s = c.call("kk")
                 # e = quickjs.Function(
                 #     "kk",
                 #     """
@@ -555,3 +594,14 @@ class Common(execute.Execute, prepare.Prepare):
                 return value.split("|")
         else:
             return []
+
+    def b64encode(self, s):
+        if not isinstance(s, bytes):
+            s = s.encode()
+        return bytearray(base64.b64encode(s)).decode()
+
+    def b64decode(self, s, ignore=1):
+        str = base64.b64decode(s)
+        if ignore and isinstance(str, bytes):
+            str = str.decode("utf-8", "ignore")
+        return str
