@@ -30,10 +30,26 @@ class Execute:
         self.data["dir"] = (
             self.data.get("dir")
             or self.get("filePath")
-            or f"{self.cwd}/download/{self.data['type']}"
+            or f"{self.cwd}/download/{self.data['category']}/{self.data['type']}"
         )
+        # if self.data.get("dir"):
+        #     self.data["dir"] = self.data["dir"]
+        # elif self.get("filePath"):
+        #     self.data["dir"] = self.filePath
+        # else:
+        #     self.data[
+        #         "dir"
+        #     ] = f"{self.cwd}/download/{self.data['category']}/{self.data['type']}"
+
         if self.data["dir"].startswith("."):
             self.data["dir"] = f'{self.cwd}{self.data["dir"][1:]}'
+
+        folder = [z for z in self.data["dir"].split("/") if z]
+        for s in folder:
+            if s in ["%category", "%type", "%vid", "%title"] and s[1:] in self.data:
+                self.data["dir"] = self.data["dir"].replace(s, self.data[s[1:]])
+            elif s[0] == "%":
+                self.data["dir"] = self.data["dir"].replace(s, time.strftime(s))
         if not Path(self.data["dir"]).exists():
             os.makedirs(self.data["dir"])
 
@@ -80,9 +96,12 @@ class Execute:
 
         if self.data["streams"].get("segs"):
             print(f'      Length:        {len(self.data["streams"]["segs"])}')
+        if self.get("iniPath"):
+            print(f'      Ini:           {self.iniPath}/{self.data["type"]}.ini')
         if self.data.get("dir"):
             print(f'      Dir:           {self.data["dir"]}')
 
+
     def execute_info(self):
         print("Location:")
         print(
@@ -124,7 +143,8 @@ class Execute:
             self.data["target"] = self.data["streams"]["segs"][0]["url"]
         else:
             self.data["target"] = self.data["streams"][self.data["playback"]]
-            # 播放
+        # self.data["target"] = self.data["streams"][self.data["playback"]]
+        # 播放
         if "temp" in [self.haskey(self.data, "extra.player"), self.data["player"]]:
             self.player_temp()
         elif self.data.get("itag") and ":" in self.data["itag"]:
@@ -212,15 +232,19 @@ class Execute:
             extra = self.data["extra"]
             if "Accept-Language" in extra["headers"]:
                 del extra["headers"]["Accept-Language"]
-            call.extend(
-                [
-                    '--http-header-fields="{}"'.format(
-                        ",".join(
-                            ["{}: {}".format(k, v) for k, v in extra["headers"].items()]
+            if not extra["headers"].get("remove"):
+                call.extend(
+                    [
+                        '--http-header-fields="{}"'.format(
+                            ",".join(
+                                [
+                                    "{}:{}".format(k, v)
+                                    for k, v in extra["headers"].items()
+                                ]
+                            )
                         )
-                    )
-                ]
-            )
+                    ]
+                )
 
         if self.data.get("loop"):
             call.extend(["--loop=" + self.data["loop"]])
