@@ -29,7 +29,7 @@ class Prepare:
                 "douyin": ["webcast.amemv.com\/", "live.douyin.com"],
                 "douyu": ["www.douyu.com\/(\d+)", "(douyu.com\/topic)"],
                 "bilibili": ["(live.bilibili)"],
-                "cctv": ["(cctv.com\/live)"],
+                "cntv": ["(cctv.com\/live)"],
                 "longzhu": ["(?<!v.)longzhu.com\/(\w+)"],
                 "laifeng": ["(v.laifeng.com)"],
                 "huya": ["(www.huya.com)"],
@@ -98,7 +98,29 @@ class Prepare:
         elif params["category"] == "music":
             pass
         else:
-            dicts = {"le": {"350": "流畅", "1000": "标清"}, "youku": {"mp4sd": "标清"}}
+            dicts = {
+                "le": {"350": "流畅", "1000": "标清"},
+                "youku": {"mp4sd": "标清"},
+                "iqiyi": {
+                    "96": "210p",
+                    "100": "210p",
+                    "1": "360P",
+                    "200": "360P",
+                    "2": "540p",
+                    "21": "540p",
+                    "300": "540p",
+                    "14": "540p",
+                    "75": "540p",
+                    "4": "720p",
+                    "17": "720p",
+                    "500": "720p",
+                    "5": "1080p",
+                    "18": "1080p",
+                    "600": "1080p",
+                    "19": "4k",
+                    "10": "4k",
+                },
+            }
         try:
 
             if self.get(f"{params['category']}Quality") and self.get(
